# LMSystems SDK

The LMSystems SDK provides a simple interface for integrating and executing purchased graphs from the LMSystems marketplace in your Python applications. This SDK allows you to seamlessly connect to pre-built LangGraph workflows and execute them with your own configurations.

## Installation

Install the package using pip:

```bash
pip install lmsystems
```

## Quick Start

Here's a simple example of how to use a purchased graph:

```python
from lmsystems.purchased_graph import PurchasedGraph
from langgraph.graph import StateGraph, START, MessagesState
import os
from dotenv import load_dotenv

# Load environment variables
load_dotenv()

# Configure your graph
config = {
    "configurable": {
        "model": "anthropic",
        "anthropic_api_key": "your-api-key"
    }
}

# Set required state values
state_values = {
    "repo_url": "https://github.com/yourusername/yourrepo",
    "github_token": "your-github-token",
    "repo_path": "/path/to/repo"
}

# Initialize the purchased graph
purchased_graph = PurchasedGraph(
    graph_name="github-agent-6",
    api_key=os.environ.get("LMSYSTEMS_API_KEY"),
    config=config,
    default_state_values=state_values
)

# Create a parent graph with MessagesState schema
builder = StateGraph(MessagesState)
builder.add_node("purchased_node", purchased_graph)
builder.add_edge(START, "purchased_node")
graph = builder.compile()

# Invoke the graph
result = graph.invoke({
    "messages": [{"role": "user", "content": "what's this repo about?"}]
})

# Stream outputs (optional)
for chunk in graph.stream({
    "messages": [{"role": "user", "content": "what's this repo about?"}]
}, subgraphs=True):
    print(chunk)
```

## Authentication

### API Key
To use the SDK, you'll need an LMSystems API key. Get your API key by:
1. Creating an account at [LMSystems](https://www.lmsystems.ai)
2. Navigate to your account settings
3. Generate an API key

Store your API key securely using environment variables:
```bash
export LMSYSTEMS_API_KEY="your-api-key"
```

## Configuration

### Graph Configuration
The `config` parameter allows you to customize the behavior of your purchased graph:
- `model`: Specify the LLM provider (e.g., "anthropic", "openai")
- `*_api_key`: The corresponding API key for your chosen model
- Additional configuration options specific to your purchased graph

### State Values
`default_state_values` sets default values for required state parameters:
- Values specific to your graph's requirements
- Common examples include API tokens, URLs, and paths
- These values are merged with any input provided during invocation

## API Reference

### PurchasedGraph Class

```python
PurchasedGraph(
    graph_name: str,
    api_key: str,
    config: Optional[RunnableConfig] = None,
    default_state_values: Optional[dict[str, Any]] = None,
    base_url: str = "https://api.lmsystems.ai",
    development_mode: bool = False,
)
```

Parameters:
- `graph_name`: Name of the purchased graph
- `api_key`: Your LMSystems API key
- `config`: Optional configuration for the graph
- `default_state_values`: Default values for required state parameters
- `base_url`: LMSystems API base URL
- `development_mode`: Enable development mode features

Methods:
- `invoke()`: Execute the graph synchronously
- `ainvoke()`: Execute the graph asynchronously
- `stream()`: Stream graph outputs synchronously
- `astream()`: Stream graph outputs asynchronously

## Error Handling

The SDK provides specific exceptions for different error cases:
- `AuthenticationError`: API key or authentication issues
- `GraphError`: Graph execution or configuration issues
- `InputError`: Invalid input parameters
- `APIError`: Backend communication issues

Example error handling:
```python
from lmsystems.exceptions import LmsystemsError

try:
    result = graph.invoke(input_data)
except AuthenticationError as e:
    print(f"Authentication failed: {e}")
except GraphError as e:
    print(f"Graph execution failed: {e}")
except InputError as e:
    print(f"Invalid input: {e}")
except APIError as e:
    print(f"API communication error: {e}")
except LmsystemsError as e:
    print(f"General error: {e}")
```

## Support

For support, feature requests, or bug reports:
- Visit our [documentation](https://docs.lmsystems.ai)
- Open an issue on our [GitHub repository](https://github.com/RVCA212/lmsystems-sdk)
- Contact us at support@lmsystems.ai

## License

This project is licensed under the terms of the MIT license.